@@ -92,6 +92,7 @@ def pca_loadings(
     adata: AnnData,
     components: Union[str, Sequence[int], None] = None,
     include_lowest: bool = True,
+    n_points: Union[int, None] = None,
     show: Optional[bool] = None,
     save: Union[str, bool, None] = None,
 ):
@@ -106,9 +107,11 @@ def pca_loadings(
         For example, ``'1,2,3'`` means ``[1, 2, 3]``, first, second, third
         principal component.
     include_lowest
-        Show the genes with both highest and lowest loadings.
+        Whether to show the variables with both highest and lowest loadings.
     show
         Show the plot, do not return axis.
+    n_points
+        Number of variables to plot for each component.
     save
         If `True` or a `str`, save the figure.
         A string is appended to the default filename.
@@ -136,13 +139,22 @@ def pca_loadings(
     elif isinstance(components, str):
         components = [int(x) for x in components.split(',')]
     components = np.array(components) - 1
+
     if np.any(components < 0):
-        logg.error("Component indices must be greater than zero.")
-        return
+        raise ValueError("Component indices must be greater than zero.")
+
+    if n_points is None:
+        n_points = min(30, adata.n_vars)
+    elif adata.n_vars < n_points:
+        raise ValueError(
+            f"Tried to plot {n_points} variables, but passed anndata only has {adata.n_vars}."
+        )
+
     ranking(
         adata,
         'varm',
         'PCs',
+        n_points=n_points,
         indices=components,
         include_lowest=include_lowest,
     )
@@ -1484,7 +1496,7 @@ def embedding_density(
             ax = embedding(
                 adata,
                 basis,
-                components=components,
+                dimensions=np.array(components) - 1,  # Saved with 1 based indexing
                 color=density_col_name,
                 color_map=color_map,
                 size=dot_sizes,
@@ -1515,7 +1527,7 @@ def embedding_density(
         fig_or_ax = embedding(
             adata,
             basis,
-            components=components,
+            dimensions=np.array(components) - 1,  # Saved with 1 based indexing
             color=density_col_name,
             color_map=color_map,
             size=dot_sizes,
