@@ -28,25 +28,25 @@ def _highly_variable_genes_seurat_v3(
     """\
     See `highly_variable_genes`.
 
-    For further implemenation details see https://www.overleaf.com/read/ckptrbgzzzpg
+    For further implementation details see https://www.overleaf.com/read/ckptrbgzzzpg
 
     Returns
     -------
     Depending on `inplace` returns calculated metrics (:class:`~pd.DataFrame`) or
-    updates `.var` with the following fields
+    updates `.var` with the following fields:
 
     highly_variable : bool
-        boolean indicator of highly-variable genes
+        boolean indicator of highly-variable genes.
     **means**
-        means per gene
+        means per gene.
     **variances**
-        variance per gene
+        variance per gene.
     **variances_norm**
-        normalized variance per gene, averaged in the case of multiple batches
+        normalized variance per gene, averaged in the case of multiple batches.
     highly_variable_rank : float
-        Rank of the gene according to normalized variance, median rank in the case of multiple batches
+        Rank of the gene according to normalized variance, median rank in the case of multiple batches.
     highly_variable_nbatches : int
-        If batch_key is given, this denotes in how many batches genes are detected as HVG
+        If batch_key is given, this denotes in how many batches genes are detected as HVG.
     """
 
     try:
@@ -84,7 +84,7 @@ def _highly_variable_genes_seurat_v3(
         model = loess(x, y, span=span, degree=2)
         model.fit()
         estimat_var[not_const] = model.outputs.fitted_values
-        reg_std = np.sqrt(10 ** estimat_var)
+        reg_std = np.sqrt(10**estimat_var)
 
         batch_counts = X_batch.astype(np.float64).copy()
         # clip large values as in Seurat
@@ -305,8 +305,8 @@ def highly_variable_genes(
     """\
     Annotate highly variable genes [Satija15]_ [Zheng17]_ [Stuart19]_.
 
-    Expects logarithmized data, except when `flavor='seurat_v3'` in which
-    count data is expected.
+    Expects logarithmized data, except when `flavor='seurat_v3'`, in which count
+    data is expected.
 
     Depending on `flavor`, this reproduces the R-implementations of Seurat
     [Satija15]_, Cell Ranger [Zheng17]_, and Seurat v3 [Stuart19]_.
@@ -322,6 +322,9 @@ def highly_variable_genes(
     standard deviation. Next, the normalized variance is computed as the variance
     of each gene after the transformation. Genes are ranked by the normalized variance.
 
+    See also `scanpy.experimental.pp._highly_variable_genes` for additional flavours
+    (e.g. Pearson residuals).
+
     Parameters
     ----------
     adata
@@ -506,9 +509,10 @@ def highly_variable_genes(
                 na_position='last',
                 inplace=True,
             )
-            df['highly_variable'] = False
-            df.highly_variable.iloc[:n_top_genes] = True
-            df = df.loc[adata.var_names]
+            high_var = np.zeros(df.shape[0])
+            high_var[:n_top_genes] = True
+            df['highly_variable'] = high_var.astype(bool)
+            df = df.loc[adata.var_names, :]
         else:
             df = df.loc[adata.var_names]
             dispersion_norm = df.dispersions_norm.values
